==> deepin-shell-debug-2.0.16-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/shell/dde-shell_autogen/EWIEGA46WW/qrc_dde-shell.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // SceneWindow.qml
  0x0,0x0,0x4,0x5e,
  0x2f,
  0x2f,0x20,0x53,0x50,0x44,0x58,0x2d,0x46,0x69,0x6c,0x65,0x43,0x6f,0x70,0x79,0x72,
  0x69,0x67,0x68,0x74,0x54,0x65,0x78,0x74,0x3a,0x20,0x32,0x30,0x32,0x34,0x20,0x55,
  0x6e,0x69,0x6f,0x6e,0x54,0x65,0x63,0x68,0x20,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,
  0x65,0x20,0x54,0x65,0x63,0x68,0x6e,0x6f,0x6c,0x6f,0x67,0x79,0x20,0x43,0x6f,0x2e,
  0x2c,0x20,0x4c,0x74,0x64,0x2e,0xa,0x2f,0x2f,0xa,0x2f,0x2f,0x20,0x53,0x50,0x44,
  0x58,0x2d,0x4c,0x69,0x63,0x65,0x6e,0x73,0x65,0x2d,0x49,0x64,0x65,0x6e,0x74,0x69,
  0x66,0x69,0x65,0x72,0x3a,0x20,0x47,0x50,0x4c,0x2d,0x33,0x2e,0x30,0x2d,0x6f,0x72,
  0x2d,0x6c,0x61,0x74,0x65,0x72,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,
  0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,0x74,
  0x51,0x75,0x69,0x63,0x6b,0x2e,0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0xa,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x73,0x20,0x31,0x2e,0x30,0xa,0xa,0x41,0x70,0x70,0x6c,0x69,0x63,0x61,
  0x74,0x69,0x6f,0x6e,0x57,0x69,0x6e,0x64,0x6f,0x77,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x69,0x64,0x3a,0x20,0x72,0x6f,0x6f,0x74,0xa,0x20,0x20,0x20,0x20,0x76,0x69,
  0x73,0x69,0x62,0x6c,0x65,0x3a,0x20,0x74,0x72,0x75,0x65,0xa,0x20,0x20,0x20,0x20,
  0x77,0x69,0x64,0x74,0x68,0x3a,0x20,0x76,0x69,0x65,0x77,0x2e,0x69,0x6d,0x70,0x6c,
  0x69,0x63,0x69,0x74,0x57,0x69,0x64,0x74,0x68,0xa,0x20,0x20,0x20,0x20,0x68,0x65,
  0x69,0x67,0x68,0x74,0x3a,0x20,0x76,0x69,0x65,0x77,0x2e,0x69,0x6d,0x70,0x6c,0x69,
  0x63,0x69,0x74,0x48,0x65,0x69,0x67,0x68,0x74,0xa,0xa,0x20,0x20,0x20,0x20,0x43,
  0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x69,0x64,0x3a,0x20,0x76,0x69,0x65,0x77,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x30,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,
  0x6c,0x6c,0x3a,0x20,0x70,0x61,0x72,0x65,0x6e,0x74,0xa,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x6d,0x70,0x6c,0x69,0x63,0x69,0x74,0x57,0x69,0x64,0x74,
  0x68,0x3a,0x20,0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,
  0x65,0x6e,0x74,0x57,0x69,0x64,0x74,0x68,0x20,0x2b,0x20,0x6c,0x65,0x66,0x74,0x50,
  0x61,0x64,0x64,0x69,0x6e,0x67,0x20,0x2b,0x20,0x72,0x69,0x67,0x68,0x74,0x50,0x61,
  0x64,0x64,0x69,0x6e,0x67,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x6d,
  0x70,0x6c,0x69,0x63,0x69,0x74,0x48,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x6c,0x69,
  0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x48,0x65,
  0x69,0x67,0x68,0x74,0x20,0x2b,0x20,0x74,0x6f,0x70,0x50,0x61,0x64,0x64,0x69,0x6e,
  0x67,0x20,0x2b,0x20,0x62,0x6f,0x74,0x74,0x6f,0x6d,0x50,0x61,0x64,0x64,0x69,0x6e,
  0x67,0xa,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x63,0x6f,0x6e,0x74,0x65,
  0x6e,0x74,0x49,0x74,0x65,0x6d,0x3a,0x20,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,
  0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,
  0x64,0x3a,0x20,0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x70,0x61,0x63,0x69,0x6e,0x67,0x3a,
  0x20,0x31,0x30,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x57,0x69,0x64,0x74,0x68,0x3a,0x20,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x6c,0x65,0x74,0x20,0x76,0x61,0x6c,0x75,0x65,0x20,0x3d,0x20,0x30,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x66,0x6f,
  0x72,0x20,0x28,0x6c,0x65,0x74,0x20,0x63,0x68,0x69,0x6c,0x64,0x20,0x6f,0x66,0x20,
  0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,
  0x49,0x74,0x65,0x6d,0x2e,0x76,0x69,0x73,0x69,0x62,0x6c,0x65,0x43,0x68,0x69,0x6c,
  0x64,0x72,0x65,0x6e,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x76,0x61,0x6c,0x75,
  0x65,0x20,0x3d,0x20,0x4d,0x61,0x74,0x68,0x2e,0x6d,0x61,0x78,0x28,0x76,0x61,0x6c,
  0x75,0x65,0x2c,0x20,0x63,0x68,0x69,0x6c,0x64,0x2e,0x77,0x69,0x64,0x74,0x68,0x29,
  0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x76,0x61,0x6c,0x75,0x65,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x6d,0x6f,0x64,0x65,0x6c,
  0x3a,0x20,0x44,0x53,0x2e,0x72,0x6f,0x6f,0x74,0x41,0x70,0x70,0x6c,0x65,0x74,0x2e,
  0x61,0x70,0x70,0x6c,0x65,0x74,0x49,0x74,0x65,0x6d,0x73,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x64,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,
  0x3a,0x20,0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x63,0x6f,0x6e,0x74,
  0x65,0x6e,0x74,0x49,0x74,0x65,0x6d,0x3a,0x20,0x6d,0x6f,0x64,0x65,0x6c,0x2e,0x64,
  0x61,0x74,0x61,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x43,0x6f,0x6d,0x70,0x6f,0x6e,0x65,0x6e,0x74,0x2e,0x6f,0x6e,
  0x43,0x6f,0x6d,0x70,0x6c,0x65,0x74,0x65,0x64,0x3a,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x49,0x74,0x65,0x6d,0x2e,0x70,0x61,0x72,
  0x65,0x6e,0x74,0x20,0x3d,0x20,0x74,0x68,0x69,0x73,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // shell
  0x0,0x5,
  0x0,0x79,0xec,0x2c,
  0x0,0x73,
  0x0,0x68,0x0,0x65,0x0,0x6c,0x0,0x6c,
    // SceneWindow.qml
  0x0,0xf,
  0x3,0xfe,0x8a,0xdc,
  0x0,0x53,
  0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x57,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0x13,0x7b,0x7a,0x50,
  // :/shell
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0x13,0x7b,0x7a,0x50,
  // :/shell/SceneWindow.qml
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0x13,0x7b,0x7a,0x50,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-shell-debug-2.0.17-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/shell/dde-shell_autogen/EWIEGA46WW/qrc_dde-shell.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // SceneWindow.qml
  0x0,0x0,0x4,0x5e,
  0x2f,
  0x2f,0x20,0x53,0x50,0x44,0x58,0x2d,0x46,0x69,0x6c,0x65,0x43,0x6f,0x70,0x79,0x72,
  0x69,0x67,0x68,0x74,0x54,0x65,0x78,0x74,0x3a,0x20,0x32,0x30,0x32,0x34,0x20,0x55,
  0x6e,0x69,0x6f,0x6e,0x54,0x65,0x63,0x68,0x20,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,
  0x65,0x20,0x54,0x65,0x63,0x68,0x6e,0x6f,0x6c,0x6f,0x67,0x79,0x20,0x43,0x6f,0x2e,
  0x2c,0x20,0x4c,0x74,0x64,0x2e,0xa,0x2f,0x2f,0xa,0x2f,0x2f,0x20,0x53,0x50,0x44,
  0x58,0x2d,0x4c,0x69,0x63,0x65,0x6e,0x73,0x65,0x2d,0x49,0x64,0x65,0x6e,0x74,0x69,
  0x66,0x69,0x65,0x72,0x3a,0x20,0x47,0x50,0x4c,0x2d,0x33,0x2e,0x30,0x2d,0x6f,0x72,
  0x2d,0x6c,0x61,0x74,0x65,0x72,0xa,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,
  0x74,0x51,0x75,0x69,0x63,0x6b,0xa,0x69,0x6d,0x70,0x6f,0x72,0x74,0x20,0x51,0x74,
  0x51,0x75,0x69,0x63,0x6b,0x2e,0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x73,0xa,0x69,
  0x6d,0x70,0x6f,0x72,0x74,0x20,0x6f,0x72,0x67,0x2e,0x64,0x65,0x65,0x70,0x69,0x6e,
  0x2e,0x64,0x73,0x20,0x31,0x2e,0x30,0xa,0xa,0x41,0x70,0x70,0x6c,0x69,0x63,0x61,
  0x74,0x69,0x6f,0x6e,0x57,0x69,0x6e,0x64,0x6f,0x77,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x69,0x64,0x3a,0x20,0x72,0x6f,0x6f,0x74,0xa,0x20,0x20,0x20,0x20,0x76,0x69,
  0x73,0x69,0x62,0x6c,0x65,0x3a,0x20,0x74,0x72,0x75,0x65,0xa,0x20,0x20,0x20,0x20,
  0x77,0x69,0x64,0x74,0x68,0x3a,0x20,0x76,0x69,0x65,0x77,0x2e,0x69,0x6d,0x70,0x6c,
  0x69,0x63,0x69,0x74,0x57,0x69,0x64,0x74,0x68,0xa,0x20,0x20,0x20,0x20,0x68,0x65,
  0x69,0x67,0x68,0x74,0x3a,0x20,0x76,0x69,0x65,0x77,0x2e,0x69,0x6d,0x70,0x6c,0x69,
  0x63,0x69,0x74,0x48,0x65,0x69,0x67,0x68,0x74,0xa,0xa,0x20,0x20,0x20,0x20,0x43,
  0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x69,0x64,0x3a,0x20,0x76,0x69,0x65,0x77,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x70,0x61,0x64,0x64,0x69,0x6e,0x67,0x3a,0x20,0x31,0x30,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x61,0x6e,0x63,0x68,0x6f,0x72,0x73,0x2e,0x66,0x69,
  0x6c,0x6c,0x3a,0x20,0x70,0x61,0x72,0x65,0x6e,0x74,0xa,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x69,0x6d,0x70,0x6c,0x69,0x63,0x69,0x74,0x57,0x69,0x64,0x74,
  0x68,0x3a,0x20,0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,
  0x65,0x6e,0x74,0x57,0x69,0x64,0x74,0x68,0x20,0x2b,0x20,0x6c,0x65,0x66,0x74,0x50,
  0x61,0x64,0x64,0x69,0x6e,0x67,0x20,0x2b,0x20,0x72,0x69,0x67,0x68,0x74,0x50,0x61,
  0x64,0x64,0x69,0x6e,0x67,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,0x6d,
  0x70,0x6c,0x69,0x63,0x69,0x74,0x48,0x65,0x69,0x67,0x68,0x74,0x3a,0x20,0x6c,0x69,
  0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x48,0x65,
  0x69,0x67,0x68,0x74,0x20,0x2b,0x20,0x74,0x6f,0x70,0x50,0x61,0x64,0x64,0x69,0x6e,
  0x67,0x20,0x2b,0x20,0x62,0x6f,0x74,0x74,0x6f,0x6d,0x50,0x61,0x64,0x64,0x69,0x6e,
  0x67,0xa,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x63,0x6f,0x6e,0x74,0x65,
  0x6e,0x74,0x49,0x74,0x65,0x6d,0x3a,0x20,0x4c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,
  0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x69,
  0x64,0x3a,0x20,0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x73,0x70,0x61,0x63,0x69,0x6e,0x67,0x3a,
  0x20,0x31,0x30,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x57,0x69,0x64,0x74,0x68,0x3a,0x20,0x7b,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x6c,0x65,0x74,0x20,0x76,0x61,0x6c,0x75,0x65,0x20,0x3d,0x20,0x30,0xa,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x66,0x6f,
  0x72,0x20,0x28,0x6c,0x65,0x74,0x20,0x63,0x68,0x69,0x6c,0x64,0x20,0x6f,0x66,0x20,
  0x6c,0x69,0x73,0x74,0x56,0x69,0x65,0x77,0x2e,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,
  0x49,0x74,0x65,0x6d,0x2e,0x76,0x69,0x73,0x69,0x62,0x6c,0x65,0x43,0x68,0x69,0x6c,
  0x64,0x72,0x65,0x6e,0x29,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x76,0x61,0x6c,0x75,
  0x65,0x20,0x3d,0x20,0x4d,0x61,0x74,0x68,0x2e,0x6d,0x61,0x78,0x28,0x76,0x61,0x6c,
  0x75,0x65,0x2c,0x20,0x63,0x68,0x69,0x6c,0x64,0x2e,0x77,0x69,0x64,0x74,0x68,0x29,
  0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x72,0x65,0x74,0x75,0x72,0x6e,0x20,0x76,0x61,0x6c,0x75,0x65,0xa,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0xa,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x6d,0x6f,0x64,0x65,0x6c,
  0x3a,0x20,0x44,0x53,0x2e,0x72,0x6f,0x6f,0x74,0x41,0x70,0x70,0x6c,0x65,0x74,0x2e,
  0x61,0x70,0x70,0x6c,0x65,0x74,0x49,0x74,0x65,0x6d,0x73,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x64,0x65,0x6c,0x65,0x67,0x61,0x74,0x65,
  0x3a,0x20,0x43,0x6f,0x6e,0x74,0x72,0x6f,0x6c,0x20,0x7b,0xa,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x63,0x6f,0x6e,0x74,
  0x65,0x6e,0x74,0x49,0x74,0x65,0x6d,0x3a,0x20,0x6d,0x6f,0x64,0x65,0x6c,0x2e,0x64,
  0x61,0x74,0x61,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x43,0x6f,0x6d,0x70,0x6f,0x6e,0x65,0x6e,0x74,0x2e,0x6f,0x6e,
  0x43,0x6f,0x6d,0x70,0x6c,0x65,0x74,0x65,0x64,0x3a,0x20,0x7b,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
  0x20,0x63,0x6f,0x6e,0x74,0x65,0x6e,0x74,0x49,0x74,0x65,0x6d,0x2e,0x70,0x61,0x72,
  0x65,0x6e,0x74,0x20,0x3d,0x20,0x74,0x68,0x69,0x73,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,
  0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x20,
  0x20,0x20,0x20,0x7d,0xa,0x20,0x20,0x20,0x20,0x7d,0xa,0x7d,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // shell
  0x0,0x5,
  0x0,0x79,0xec,0x2c,
  0x0,0x73,
  0x0,0x68,0x0,0x65,0x0,0x6c,0x0,0x6c,
    // SceneWindow.qml
  0x0,0xf,
  0x3,0xfe,0x8a,0xdc,
  0x0,0x53,
  0x0,0x63,0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x57,0x0,0x69,0x0,0x6e,0x0,0x64,0x0,0x6f,0x0,0x77,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0x1a,0x48,0xf2,0xb8,
  // :/shell
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0x1a,0x48,0xf2,0xb8,
  // :/shell/SceneWindow.qml
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0x1a,0x48,0xf2,0xb8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_dde_shell)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_dde_shell)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
